==> jc-1.4.0.tar.gz: gnu/regexp/RETokenBackRef.h <==
// final class gnu.regexp.RETokenBackRef

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class 4f608bd40671c1bc gnu_regexp_RETokenBackRef
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenBackRef_H_
#define _JC_gnu_regexp_RETokenBackRef_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenBackRef$sub_refs	_jc_gnu_regexp_RETokenBackRef$sub_refs;
typedef struct _jc_gnu_regexp_RETokenBackRef$sub_nonrefs	_jc_gnu_regexp_RETokenBackRef$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenBackRef$refs	_jc_gnu_regexp_RETokenBackRef$refs;
typedef struct _jc_gnu_regexp_RETokenBackRef$nonrefs	_jc_gnu_regexp_RETokenBackRef$nonrefs;
typedef struct _jc_gnu_regexp_RETokenBackRef$object	_jc_gnu_regexp_RETokenBackRef$object;

typedef const struct _jc_gnu_regexp_RETokenBackRef$vmethods	_jc_gnu_regexp_RETokenBackRef$vmethods;
typedef const struct _jc_gnu_regexp_RETokenBackRef$vtable	_jc_gnu_regexp_RETokenBackRef$vtable;
typedef const struct _jc_gnu_regexp_RETokenBackRef$vtype	_jc_gnu_regexp_RETokenBackRef$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenBackRef$method$_init$aabfffe230c84c7b(_jc_env *, struct _jc_gnu_regexp_RETokenBackRef$object *, jint, jint, jboolean);

// Virtual methods
extern void _jc_gnu_regexp_RETokenBackRef$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenBackRef$object *, struct _jc_java_lang_StringBuffer$object *);
extern jboolean _jc_gnu_regexp_RETokenBackRef$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenBackRef$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenBackRef$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenBackRef$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenBackRef$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenBackRef$object *, struct _jc_java_lang_StringBuffer$object *);
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenBackRef$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
};

// Vtable
struct _jc_gnu_regexp_RETokenBackRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenBackRef$vmethods	gnu_regexp_RETokenBackRef;
};

// Vtype
struct _jc_gnu_regexp_RETokenBackRef$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenBackRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenBackRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenBackRef$refs {
    _jc_gnu_regexp_RETokenBackRef$sub_refs	gnu_regexp_RETokenBackRef;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenBackRef$sub_nonrefs {
	jint	num;
	jboolean	insens;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenBackRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenBackRef$sub_nonrefs	gnu_regexp_RETokenBackRef;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenBackRef$object {
	_jc_gnu_regexp_RETokenBackRef$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenBackRef$vtype	*vtype;
	_jc_gnu_regexp_RETokenBackRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenBackRef$vtype _jc_gnu_regexp_RETokenBackRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenBackRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenBackRef$class_object;

#endif	/* _JC_gnu_regexp_RETokenBackRef_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/RETokenBackRef.h <==
// final class gnu.regexp.RETokenBackRef

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class 4f608bd40671c1bc gnu_regexp_RETokenBackRef
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenBackRef_H_
#define _JC_gnu_regexp_RETokenBackRef_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenBackRef$sub_refs	_jc_gnu_regexp_RETokenBackRef$sub_refs;
typedef struct _jc_gnu_regexp_RETokenBackRef$sub_nonrefs	_jc_gnu_regexp_RETokenBackRef$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenBackRef$refs	_jc_gnu_regexp_RETokenBackRef$refs;
typedef struct _jc_gnu_regexp_RETokenBackRef$nonrefs	_jc_gnu_regexp_RETokenBackRef$nonrefs;
typedef struct _jc_gnu_regexp_RETokenBackRef$object	_jc_gnu_regexp_RETokenBackRef$object;

typedef const struct _jc_gnu_regexp_RETokenBackRef$vmethods	_jc_gnu_regexp_RETokenBackRef$vmethods;
typedef const struct _jc_gnu_regexp_RETokenBackRef$vtable	_jc_gnu_regexp_RETokenBackRef$vtable;
typedef const struct _jc_gnu_regexp_RETokenBackRef$vtype	_jc_gnu_regexp_RETokenBackRef$vtype;

// Constructors
extern void _jc_gnu_regexp_RETokenBackRef$method$_init$aabfffe230c84c7b(_jc_env *, struct _jc_gnu_regexp_RETokenBackRef$object *, jint, jint, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_regexp_RETokenBackRef$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenBackRef$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RETokenBackRef$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenBackRef$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenBackRef$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenBackRef$method_info$match$d139de67a06a4f32;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenBackRef$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenBackRef$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenBackRef$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_RETokenBackRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenBackRef$vmethods	gnu_regexp_RETokenBackRef;
};

// Vtype
struct _jc_gnu_regexp_RETokenBackRef$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenBackRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenBackRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenBackRef$refs {
    _jc_gnu_regexp_RETokenBackRef$sub_refs	gnu_regexp_RETokenBackRef;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenBackRef$sub_nonrefs {
	jint	num;
	jboolean	insens;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenBackRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenBackRef$sub_nonrefs	gnu_regexp_RETokenBackRef;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenBackRef$object {
	_jc_gnu_regexp_RETokenBackRef$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenBackRef$vtype	*vtype;
	_jc_gnu_regexp_RETokenBackRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenBackRef$vtype _jc_gnu_regexp_RETokenBackRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenBackRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenBackRef$class_object;

#endif	/* _JC_gnu_regexp_RETokenBackRef_H_ */
